@@ -39,12 +39,20 @@ aSPUboot <- function(Y, X, cov=NULL, model=c("gaussian", "binomial"), pow=c(1:8,
     if (is.null(X) && length(X)>0) X=as.matrix(X, ncol=1)
     k <- ncol(X)
 
+
     if (is.null(cov)){
         ## NO nuisance parameters:
         Xg <- X
         U<-t(Xg) %*% (Y-mean(Y))
     } else {
         tdat1<-data.frame(trait=Y, cov)
+
+        if(is.null(colnames(cov))) {
+            colnames(tdat1) = c("trait", paste("cov",1:dim(cov)[2],sep=""))
+        } else {
+            colnames(tdat1) = c("trait", colnames(cov))
+        }
+
         fit1<-glm(trait~., family=model, data=tdat1)
         pis<-fitted.values(fit1)
         Us<-XUs<-matrix(0, nrow=n, ncol=k)
